| thompson | R Documentation |
The randomization probability for each arm is determined by raising the
posterior probability of that arm being the best studied arm to the power
kappa given as a parameter.
thompson(kappa)
Other allocation rules:
allocation_rule,
arjas_gasbarra(),
random_allocation(),
randomization_list()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.